@@ -32,12 +32,15 @@ def _flatten_cluster(obj):
         'status': obj.status.status,
         'type': obj.spec.type,
         'flavor': obj.spec.flavor,
-        'endpoint': obj.status.endpoints.get('external_otc'),
         'router_id': obj.spec.host_network.router_id,
         'network_id': obj.spec.host_network.network_id,
         'version': obj.spec.version
     }
 
+    endpoints = obj.status.get('endpoints')
+    if endpoints:
+        data['endpoint'] = endpoints.get('external_otc')
+
     return data
 
 
@@ -79,7 +82,7 @@ class ShowCCECluster(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.cce
 
-        obj = client.find_cluster(parsed_args.cluster)
+        obj = client.find_cluster(parsed_args.cluster, ignore_missing=False)
 
         # display_columns, columns = _get_columns(obj)
         data = utils.get_dict_properties(_flatten_cluster(obj), self.columns)
@@ -126,6 +129,8 @@ class DeleteCCECluster(command.Command):
         if not parsed_args.wait:
             attrs['wait'] = False
 
+        # initialize sdk_connection with cce methods
+        _ = self.app.client_manager.cce
         if parsed_args.cluster:
             self.app.client_manager.sdk_connection.delete_cce_cluster(
                 **attrs
@@ -186,7 +191,7 @@ class CreateCCECluster(command.ShowOne):
             metavar='{' + ','.join(CONTAINER_NET_MODE_CHOICES) + '}',
             type=lambda s: s.lower(),
             choices=CONTAINER_NET_MODE_CHOICES,
-            required=True,
+            default='overlay_l2',
             help=_('Container network mode.')
         )
         parser.add_argument(
@@ -231,6 +236,8 @@ class CreateCCECluster(command.ShowOne):
         if parsed_args.multi_az:
             attrs['az'] = 'multi_az'
 
+        # initialize sdk_connection with cce methods
+        _ = self.app.client_manager.cce
         obj = self.app.client_manager.sdk_connection.create_cce_cluster(
             **attrs)
 
