@@ -16,6 +16,8 @@ from otcextensions.sdk.dcs.v1 import config as _config
 from otcextensions.sdk.dcs.v1 import instance as _instance
 from otcextensions.sdk.dcs.v1 import restore_record as _restore_record
 from otcextensions.sdk.dcs.v1 import statistic as _stat
+from otcextensions.sdk.dcs.v1 import quota as _quota
+from otcextensions.sdk.dcs.v1 import maintenance_time_window as _maintenance_tw
 
 
 class Proxy(proxy.Proxy):
@@ -262,3 +264,28 @@ class Proxy(proxy.Proxy):
             self,
             params
         )
+
+    # ======== Quotas ========
+    def quotas(self):
+        """Return a generator of quotas
+
+        :returns: A generator of quota objects
+        :rtype: :class:`~otcextensions.sdk.dcs.v1.quota.Quota`
+        """
+        return self._list(_quota.Quota)
+
+    # ======== Maintenance Time Window ========
+    def maintenance_time_windows(self):
+        """Return a generator of maintenance time windows
+
+        :returns: A generator of maintenance time window objects
+        :rtype: :class:`~otcextensions.sdk.dcs.v1.maintenance_time_window
+        .MaintenanceTimeWindow
+        """
+        endpoint = _maintenance_tw.MaintenanceTimeWindow._get_session(
+            self).get_endpoint().split('/%').pop(0)
+        base_path = endpoint + '/instances/maintain-windows'
+
+        return self._list(
+            resource_type=_maintenance_tw.MaintenanceTimeWindow,
+            base_path=base_path)
